Excel Spreadsheet — linkml documentation

# Excel Spreadsheet

This generator allows you to create a spreadsheet representation of your LinkML schema.

## Example Output

Using the Person LinkML schema as input, the generated Excel spreadsheet looks as follows: personinfo.xlsx

## Overview

You can create an Excel template of a LinkML schema as follows:

    gen-excel ~/path/to/personinfo.yaml --output ~/path/to/personinfo.xlsx

Currently, in the generated Excel workbook there can be one or more associated worksheets, each corresponding to classes from the LinkML schema.

The generator also supports validation at the enum level. In that, each slot with a range property that is of enum type will have associated drop downs for all cells corresponding to that slot in the excel spreadsheet.

Note: It works best for “flat” or denormalized schemas.

Additional validation support to be added:

- Color schemes to indicate whether a field is required or recommended

- Constraints based on the range of a slot, e.g. constraining int fields to be numbers

- Tooltip notes describing what each field indicates

## Docs

### Command Line

#### gen-excel

Generate Excel representation of a LinkML model

    gen-excel [OPTIONS] YAMLFILE

Options

-o, --output <output>

  Name of Excel spreadsheet to be created

-f, --format <format>

  Output format (default=xlsx)

  Options

    xlsx

--metadata, --no-metadata

  Include metadata in output (default=–metadata)

--useuris, --metauris

  Include metadata in output (default=–useuris)

-im, --importmap <importmap>

  Import mapping file

--log_level <log_level>

  Logging level (default=WARNING)

  Options

    CRITICAL | ERROR | WARNING | INFO | DEBUG

--mergeimports, --no-mergeimports

  Merge imports into source file (default=mergeimports)

Arguments

YAMLFILE

  Required argument

### Code